==> web-10.1.0.tgz: package/lib/menu/ParMenu.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { SlideBox } from "../animate/index";
class ParMenu extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.selectItemFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            const indexArr = index.split(",");
            const { changeData } = this.props;
            changeData(function (_data, selected) {
                const oldSelectedArr = selected.split(",");
                let data = _data;
                if (oldSelectedArr.length === 2) {
                    data = data.updateIn([oldSelectedArr[0]], (node) => node.set("selected", false).updateIn(["children", oldSelectedArr[1]], (item) => item.set("selected", false)));
                }
                data = data.updateIn([indexArr[0]], (node) => node.set("selected", true).updateIn(["children", indexArr[1]], (item) => item.set("selected", true)));
                return {
                    data,
                    selected: index
                };
            });
        };
        this.slideCallback = (isStart) => {
            const { scrollInitFn } = this.props;
            if (!isStart && scrollInitFn) {
                scrollInitFn.initScroll();
            }
        };
        this.toggleSlide = () => {
            this.props.toggleSlide(this.props.parIndex);
        };
    }
    subMenu(children, parIndex) {
        const { fieldObj, link } = this.props;
        const idField = fieldObj.get("id");
        const textField = fieldObj.get("text");
        const urlField = fieldObj.get("url");
        return children.map((node, index) => {
            const id = node.get(idField);
            const text = node.get(textField);
            const activeName = node.get("selected") ? "active" : "";
            const url = node.get(urlField);
            const typeId = node.get("type") || "";
            const pathObj = {
                pathname: url,
                state: {
                    typeId: `${typeId}`,
                    text,
                }
            };
            return (React.createElement("li", { className: "li-child", key: id },
                React.createElement("div", { className: `menu-item menu-child ${activeName}` },
                    React.createElement("span", { className: "j-nav", "data-index": `${parIndex},${index}`, "data-id": id, onClick: this.selectItemFn }, !link ? text : link(pathObj)))));
        });
    }
    getSubCom() {
        const { node, expand, parIndex } = this.props;
        const child = node.get("children");
        const subCom = (React.createElement("ul", { className: "child-ul" }, this.subMenu(child, parIndex)));
        return expand ? (React.createElement(SlideBox, { slide: node.get("drop"), isImmedia: true, slideFnCallback: this.slideCallback }, subCom)) : subCom;
    }
    render() {
        const { node, fieldObj, expand } = this.props;
        const drop = node.get("drop");
        const activeName = node.get("selected") ? "active" : "";
        const slideName = node.get("drop") ? "slideDown" : "slideUp";
        const icon = node.get(fieldObj.get("icon"));
        const text = node.get(fieldObj.get("text"));
        const sub = this.getSubCom();
        return (React.createElement("li", { className: "li-par" },
            React.createElement("div", { className: `menu-item menu-par ${activeName} ${slideName}`, onClick: expand ? this.toggleSlide : undefined },
                React.createElement("span", { className: "m-txt" },
                    React.createElement("span", { className: "par-icon" },
                        React.createElement(SvgIcon, { className: icon })),
                    React.createElement("span", { className: "nav-text" }, text)),
                React.createElement("span", { className: "m-slide-icon" },
                    React.createElement(SvgIcon, { className: `arrow-${drop ? "down" : "right"}` }))),
            sub));
    }
}
export default ParMenu;

==> web-11.0.2.tgz: package/lib/menu/ParMenu.js <==
import * as React from "react";
import { SvgIcon } from "../my-icon/index";
import { SlideBox } from "../animate/index";
class ParMenu extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.selectItemFn = (e) => {
            const dom = e.currentTarget;
            const index = dom.dataset.index;
            const indexArr = index.split(",");
            const { changeData } = this.props;
            changeData(function (_data, selected) {
                const oldSelectedArr = selected.split(",");
                let data = _data;
                data = data.updateIn([oldSelectedArr[0]], (node) => node ? node.set("selected", false).updateIn(["children", oldSelectedArr[1]], (item) => item ? item.set("selected", false) : item) : node);
                data = data.updateIn([indexArr[0]], (node) => node ? node.set("selected", true).updateIn(["children", indexArr[1]], (item) => item ? item.set("selected", true) : item) : node);
                return {
                    data,
                    selected: index
                };
            });
        };
        this.slideCallback = (isStart) => {
            const { scrollInitFn } = this.props;
            if (!isStart && scrollInitFn) {
                scrollInitFn.initScroll();
            }
        };
        this.toggleSlide = () => {
            this.props.toggleSlide(this.props.parIndex);
        };
    }
    subMenu(children, parIndex) {
        const { fieldObj, link } = this.props;
        const idField = fieldObj.get("id");
        const textField = fieldObj.get("text");
        const urlField = fieldObj.get("url");
        return children.map((node, index) => {
            const id = node.get(idField);
            const text = node.get(textField);
            const activeName = node.get("selected") ? "active" : "";
            const url = node.get(urlField);
            const typeId = node.get("type") || "";
            const pathObj = {
                pathname: url,
                state: {
                    typeId: `${typeId}`,
                    text,
                }
            };
            return (React.createElement("li", { className: "li-child", key: id },
                React.createElement("div", { className: `menu-item menu-child ${activeName}` },
                    React.createElement("span", { className: "j-nav", "data-index": `${parIndex},${index}`, "data-id": id, onClick: this.selectItemFn }, !link ? text : link(pathObj)))));
        });
    }
    getSubCom() {
        const { node, expand, parIndex } = this.props;
        const child = node.get("children");
        const subCom = (React.createElement("ul", { className: "child-ul" }, this.subMenu(child, parIndex)));
        return expand ? (React.createElement(SlideBox, { slide: node.get("drop"), isImmedia: true, slideFnCallback: this.slideCallback }, subCom)) : subCom;
    }
    renderPar() {
        const { node, fieldObj, expand } = this.props;
        const drop = node.get("drop");
        const activeName = node.get("selected") ? "active" : "";
        const slideName = node.get("drop") ? "slideDown" : "slideUp";
        const icon = node.get(fieldObj.get("icon"));
        const text = node.get(fieldObj.get("text"));
        const sub = this.getSubCom();
        return (React.createElement("li", { className: "li-par" },
            React.createElement("div", { className: `menu-item menu-par ${activeName} ${slideName}`, onClick: expand ? this.toggleSlide : undefined },
                React.createElement("span", { className: "m-txt" },
                    React.createElement("span", { className: "par-icon" },
                        React.createElement(SvgIcon, { className: icon })),
                    React.createElement("span", { className: "nav-text" }, text)),
                React.createElement("span", { className: "m-slide-icon" },
                    React.createElement(SvgIcon, { className: `arrow-${drop ? "down" : "right"}` }))),
            sub));
    }
    renderSingleNav() {
        const { node, fieldObj, link, parIndex, expand } = this.props;
        const activeName = node.get("selected") ? "active" : "";
        const icon = node.get(fieldObj.get("icon"));
        const text = node.get(fieldObj.get("text"));
        const id = node.get(fieldObj.get("id"));
        const url = node.get(fieldObj.get("url"));
        const typeId = node.get("type") || "";
        const pathObj = {
            pathname: url,
            state: {
                typeId: `${typeId}`,
                text,
            }
        };
        const subCom = expand ? null : (React.createElement("ul", { className: "child-ul" },
            React.createElement("li", { className: "li-child" },
                React.createElement("div", { className: `menu-item menu-child ${activeName}` },
                    React.createElement("span", { className: "j-nav", "data-index": `${parIndex}`, "data-id": id, onClick: this.selectItemFn }, !link ? text : link(pathObj))))));
        return (React.createElement("li", { className: "li-par" },
            React.createElement("div", { className: `menu-item menu-par ${activeName}` },
                React.createElement("span", { className: "m-txt" },
                    React.createElement("span", { className: "par-icon" },
                        React.createElement(SvgIcon, { className: icon })),
                    React.createElement("span", { className: "j-nav nav-text", "data-index": `${parIndex}`, "data-id": id, onClick: this.selectItemFn }, !link ? text : link(pathObj)))),
            subCom));
    }
    render() {
        const { node } = this.props;
        return node.get("children").size ? this.renderPar() : this.renderSingleNav();
    }
}
export default ParMenu;
